@@ -4,13 +4,41 @@ use strict;
 use warnings;
 use Aspect::Pointcut::Logic ();
 
-our $VERSION = '0.97_05';
+our $VERSION = '0.97_06';
 our @ISA     = 'Aspect::Pointcut::Logic';
 
 
 
 
 
+######################################################################
+# Constructor
+
+sub new {
+	my $class = shift;
+	my @parts = @_;
+
+	# Validate the pointcut subexpressions
+	foreach my $part ( @parts ) {
+		next if Params::Util::_INSTANCE($part, 'Aspect::Pointcut');
+		Carp::croak("Attempted to apply pointcut logic to non-pointcut '$part'");
+	}
+
+	# Collapse nested and statements at constructor time so we don't have
+	# to do so multiple times later on during currying.
+	while ( scalar grep { $_->isa('Aspect::Pointcut::And') } @parts ) {
+		@parts = map {
+			$_->isa('Aspect::Pointcut::And') ? @$_ : $_
+		} @parts;
+	}
+
+	$class->SUPER::new(@parts);
+}
+
+
+
+
+
 ######################################################################
 # Weaving Methods
 
@@ -140,13 +168,6 @@ sub curry_weave {
 	my $self = shift;
 	my @list = @$self;
 
-	# Collapse nested ::And clauses
-	while ( scalar grep { $_->isa('Aspect::Pointcut::And') } @list ) {
-		@list = map {
-			$_->isa('Aspect::Pointcut::And') ? @$_ : $_
-		} @list;
-	}
-
 	# Curry down our children. Anything that is not relevant at weave
 	# time is considered to always match, but curries to null.
 	# In an AND scenario, any "always" match can be savely removed.
@@ -166,13 +187,6 @@ sub curry_runtime {
 	my $self = shift;
 	my @list = @$self;
 
-	# Collapse nested ::And clauses
-	while ( scalar grep { $_->isa('Aspect::Pointcut::And') } @list ) {
-		@list = map {
-			$_->isa('Aspect::Pointcut::And') ? @$_ : $_
-		} @list;
-	}
-
 	# Should we strip out the call pointcuts
 	my $strip = shift;
 	unless ( defined $strip ) {
