@@ -8,18 +8,9 @@ use Carp             ();
 use Params::Util     ();
 use Aspect::Pointcut ();
 
-our $VERSION = '0.97_05';
+our $VERSION = '0.97_06';
 our @ISA     = 'Aspect::Pointcut';
 
-sub new {
-	my $class = shift;
-	foreach ( @_ ) {
-		next if Params::Util::_INSTANCE($_, 'Aspect::Pointcut');
-		Carp::croak("Attempted to apply pointcut logic to non-pointcut '$_'");
-	}
-	$class->SUPER::new(@_);
-}
-
 sub match_runtime {
 	return 0;
 }
