@@ -4,13 +4,41 @@ use strict;
 use warnings;
 use Aspect::Pointcut::Logic ();
 
-our $VERSION = '0.97_05';
+our $VERSION = '0.97_06';
 our @ISA     = 'Aspect::Pointcut::Logic';
 
 
 
 
 
+######################################################################
+# Constructor
+
+sub new {
+	my $class = shift;
+	my @parts = @_;
+
+	# Validate the pointcut subexpressions
+	foreach my $part ( @parts ) {
+		next if Params::Util::_INSTANCE($part, 'Aspect::Pointcut');
+		Carp::croak("Attempted to apply pointcut logic to non-pointcut '$part'");
+	}
+
+	# Collapse nested or statements at constructor time so we don't have
+	# to do so multiple times later on during currying.
+	while ( scalar grep { $_->isa('Aspect::Pointcut::Or') } @parts ) {
+		@parts = map {
+			$_->isa('Aspect::Pointcut::Or') ? @$_ : $_
+		} @parts;
+	}
+
+	$class->SUPER::new(@parts);
+}
+
+
+
+
+
 ######################################################################
 # Weaving Methods
 
@@ -119,13 +147,6 @@ sub curry_weave {
 	my $self = shift;
 	my @list = @$self;
 
-	# Collapse nested logical clauses
-	while ( scalar grep { $_->isa('Aspect::Pointcut::Or') } @list ) {
-		@list = map {
-			$_->isa('Aspect::Pointcut::Or') ? @$_ : $_
-		} @list;
-	}
-
 	# Curry down our children. Any null element always matches, and
 	# therefore in an OR scenario the entire expression always matches.
 	my @or = ();
@@ -148,13 +169,6 @@ sub curry_runtime {
 	my $self = shift;
 	my @list = @$self;
 
-	# Collapse nested logical clauses
-	while ( scalar grep { $_->isa('Aspect::Pointcut::Or') } @list ) {
-		@list = map {
-			$_->isa('Aspect::Pointcut::Or') ? @$_ : $_
-		} @list;
-	}
-
 	# Should we strip out the call pointcuts
 	my $strip = shift;
 	unless ( defined $strip ) {
